#
# spec file for package python-parsimonious
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-parsimonious
Version:        0.10.0
Release:        2.1
Summary:        Pure-Python PEG parser
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/erikrose/parsimonious
Source:         https://files.pythonhosted.org/packages/source/p/parsimonious/parsimonious-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module regex}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-regex
BuildArch:      noarch
%python_subpackages

%description
Parsimonious is an arbitrary-lookahead parser written in pure
Python. It's based on parsing expression grammars (PEGs), which
means you feed it a simplified sort of EBNF notation.

%prep
%autosetup -p1 -n parsimonious-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/parsimonious
%{python_sitelib}/parsimonious-%{version}*-info

%changelog
* Tue Jun  3 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Wed Mar  8 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * Fix infinite recursion in __eq__ in some cases. (FelisNivalis)
  * Improve error message in left-recursive rules. (lucaswiman)
  * Add support for range ``{min,max}`` repetition expressions (righthandabacus)
  * Fix bug in ``*`` and ``+`` for token grammars (lucaswiman)
  * Add support for grammars on bytestrings (lucaswiman)
  * Fix LazyReference resolution bug #134 (righthandabacus)
  * ~15%% speedup on benchmarks with a faster node cache (ethframe)
  * This release makes backward-incompatible changes:
  * Fix precedence of string literal modifiers ``u/r/b``.
    This will break grammars with no spaces between a
    reference and a string literal. (lucaswiman)
  * Add support for Python 3.7, 3.8, 3.9, 3.10 (righthandabacus, Lonnen)
  * Drop support for Python 2.x, 3.3, 3.4 (righthandabacus, Lonnen)
  * Remove six and go all in on Python 3 idioms (Lonnen)
  * Replace re with regex for improved handling of unicode characters
    in regexes (Oderjunkie)
  * Dropped nose for unittest (swayson)
  * `Grammar.__repr__()` now correctly escapes backslashes (ingolemo)
  * Custom rules can now be class methods in addition to
    functions (James Addison)
  * Make the ascii flag available in the regex syntax (Roman Inflianskas)
- drop replace-nose.patch (upstream)
* Mon Apr 20 2020 Matej Cepl <mcepl@suse.com>
- Add replace-nose.patch which replaces use of nose with the
  standard library (gh#erikrose/parsimonious#160)
- Switch from using nose runner to pytest
* Mon Dec 23 2019 Martin Herkt <9+suse@cirno.systems>
- init, version 0.8.1
